SecurityEvent class

A security event triggered by the plugin.

Constructors

SecurityEvent({required SecurityEventType type, String message = '', dynamic details})

Properties

details → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type SecurityEventType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited