SecurityDialog class
A modern, red-themed alert dialog for security threats.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- SecurityDialog
Constructors
- SecurityDialog({Key? key, required SecurityEvent event, String? title, String? message, bool canPop = false, VoidCallback? onRefresh, Color? primaryColor, IconData? icon, VoidCallback? onDismiss})
-
const
Properties
- canPop → bool
-
Whether the dialog can be dismissed. Default is false.
final
- event → SecurityEvent
-
The security event that triggered this dialog.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → IconData?
-
Custom icon for the header.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- message → String?
-
Optional custom message for the dialog.
final
- onDismiss → VoidCallback?
-
Callback when the close button is pressed.
final
- onRefresh → VoidCallback?
-
Callback when the refresh button is pressed.
final
- primaryColor → Color?
-
Primary color for the dialog (header and button).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
Optional custom title for the dialog.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited